@@ -2,7 +2,7 @@ package LWP::Protocol::http;
 
 use strict;
 
-our $VERSION = '6.75';
+our $VERSION = '6.76';
 
 require HTTP::Response;
 require HTTP::Status;
@@ -49,8 +49,7 @@ sub _new_socket
 	die "$status\n\n$@";
     }
 
-    # perl 5.005's IO::Socket does not have the blocking method.
-    eval { $sock->blocking(0); };
+    $sock->blocking(0);
 
     $sock;
 }
